# set default variables for all Makefiles here
# We do not want to have /bin/sh called by accident, so we set this explicitly
# to match the command line shell
PROJECT=/tmp/bennet
SHELL=/bin/bash
export SHELL

# egrep -o <pattern> extracts the matching pattern from the directory name
# that is given to it by pwd.  So, from the current directory, whatever it
# might be, it will find 'sub' followed by three digits, if it exists.
subject=$(shell pwd | egrep -o sub[0-9][0-9][0-9])

# We have to tell make that no files are produced by clean-bet
.PHONY: clean-bet test

test:
	@echo ; echo "Testing we are making $(subject) from $(PWD)" ; echo

# You should always define what the all target is to prevent accidents
# We want it to create the extracted brain file
# all: highres_brain001.nii.gz

# You will be wise to include the definitions of the ugly variables in each
# Makefile. Additionally, other obscure syntax should be explicated in each
# file.  At some point, you will have new people reading these, and this is
# for them; you will also forget what the arbitrary sequences of punctuation
# mean, so helping others is also helping yourself.

# Ugly variable definitions
#    $@ is the filename of the target
#    $< is the first item from the dependency list (first prerequisite)

highres001_brain.nii.gz: highres001.nii.gz
	@date > run_bet.log
	@echo "=====> Running: bet $@ $< -m -R" >> run_bet.log
	@echo "=====>   from $(PWD)" >> run_bet.log
	@echo bet $< $@ -m -R
	@touch highres001_brain.nii.gz highres001_brain_mask.nii.gz
	@echo

# If you have bet installed and wish to run it rather than simulate, delete
# the @echo and its following space from the line that reads
#      @echo bet $< $@ -m -R
# and remove the @touch line.

# If, for some reason, you want to reprocess, this removes the files created
# by the highres001_brain.nii.gz rule.
clean-bet:
	pwd
	rm -f highres001_brain.nii.gz highres001_brain_mask.nii.gz run_bet.log

# An alternate way to do the rm is
#
# -rm highres001_brain.nii.gz highres001_brain_mask.nii.gz run_bet.log
#
# Adding the dash in front of the rm command instructs make to ignore
# any errors that it might produce and continue anyway. You may prefer
# that, if you there are errors that you would be interested in. Here,
# I prefer to use the -f flag to rm which suppresses its errors; clean
# is clean, whether I ask to clean something that is or not.
